@@ -17,14 +17,9 @@
 #define	Nbby           8	/* number of bits/byte */
 
 #define MAXARGS	    1000	/* max arguments to exec                */
-#define NFOLDERS     300	/* max folder arguments on command line */
+#define NFOLDERS    1000	/* max folder arguments on command line */
 #define DMAXFOLDER     4	/* typical number of digits             */
-
-#ifndef	UCI
-# define MAXFOLDER  1000	/* message increment */
-#else
-# define MAXFOLDER  1500	/* message increment */
-#endif
+#define MAXFOLDER   1000	/* message increment                    */
 
 /*
  * user context/profile structure
@@ -172,6 +167,8 @@ struct msgs {
 #define make_all_public(mp) \
            ((mp)->attrstats = 0)
 
+#define other_files(mp)     ((mp)->msgflags & OTHERS)
+
 #define	NULLMP	((struct msgs *) 0)
 
 /*
