@@ -1,6 +1,6 @@
 
 /*
- * cpydata.c -- copy from one fd to another
+ * cpydata.c -- copy all data from one fd to another
  *
  * $Id$
  */
@@ -13,9 +13,10 @@ cpydata (int in, int out, char *ifile, char *ofile)
     register int i;
     char buffer[BUFSIZ];
 
-    while ((i = read(in, buffer, sizeof buffer)) > 0)
+    while ((i = read(in, buffer, sizeof(buffer))) > 0) {
 	if (write(out, buffer, i) != i)
 	    adios(ofile, "error writing");
+    }
 
     if (i == NOTOK)
 	adios(ifile, "error reading");
