@@ -22,7 +22,7 @@ getcpy (char *str)
     } else {
 	if (!(cp = malloc ((size_t) 1)))
 	    adios (NULL, "unable to allocate string storage");
-	*cp = NULL;
+	*cp = '\0';
     }
     return cp;
 }
