@@ -1,6 +1,6 @@
 
 /*
- * m_convert.c -- parse a message sequence and set SELECTED
+ * m_convert.c -- parse a message range or sequence and set SELECTED
  *
  * $Id$
  */
@@ -66,10 +66,11 @@ badelim: ;
 		*delimp, *delimp);
 	return 0;
     }
+
     if (*cp == '-') {
 	cp++;
 	if ((err = last = m_conv (mp, cp, LAST)) <= 0) {
-    badmsg: ;
+badmsg:;
 	    switch (err) {
 		case BADMSG: 
 		    advise (NULL, "no %s message", cp);
@@ -103,7 +104,7 @@ badelim: ;
 	if (*delimp)
 	    goto badelim;
 	if (first > mp->hghmsg || last < mp->lowmsg) {
-    rangerr: ;
+rangerr:;
 	    advise (NULL, "no messages in range %s", name);
 	    return 0;
 	}
@@ -111,8 +112,7 @@ badelim: ;
 	    last = mp->hghmsg;
 	if (first < mp->lowmsg)
 	    first = mp->lowmsg;
-	}
-    else
+    } else {
 	if (*cp == ':') {
 	    cp++;
 	    if (*cp == '-') {
@@ -152,8 +152,7 @@ badelim: ;
 		last = first;
 		first = range;
 	    }
-	}
-	else {
+	} else {
 	    if (!(mp->msgflags & MHPATH))
 		if (first > mp->hghmsg
 			|| first < mp->lowmsg
@@ -164,16 +163,18 @@ badelim: ;
 			advise (NULL, "message %d doesn't exist", first);
 		    return 0;
 		}
-    single: ;
+single:;
 	    last = first;
 	    if (mp->msgflags & MHPATH)
 		mp->msgstats[first] |= SELECT_EMPTY;
 	}
+    }
+
     for (; first <= last; first++)
 	if (mp->msgstats[first] & flags) {
-	    if (!(mp->msgstats[first] & SELECTED)) {
+	    if (!is_selected (mp, first)) {
+		set_selected (mp, first);
 		mp->numsel++;
-		mp->msgstats[first] |= SELECTED;
 		if (mp->lowsel == 0 || first < mp->lowsel)
 		    mp->lowsel = first;
 		if (first > mp->hghsel)
@@ -207,10 +208,10 @@ m_conv (struct msgs *mp, char *str, int call)
     }
 
     bp = buf;
-#ifndef LOCALE
-    while ((*cp >= 'a' && *cp <= 'z') || *cp == '.')
-#else
+#ifdef LOCALE
     while (isalpha(*cp) || *cp == '.')	/* doesn't enforce lower case */
+#else
+    while ((*cp >= 'a' && *cp <= 'z') || *cp == '.')
 #endif /* LOCALE */
 	*bp++ = *cp++;
     *bp++ = 0;
@@ -256,8 +257,7 @@ static int
 attr (struct msgs *mp, char *cp)
 {
     char *bp = NULL;
-    int bits,
-        found,
+    int found,
         inverted,
         range = 0,		/* no range */
 	first = 0;
@@ -320,8 +320,6 @@ attr (struct msgs *mp, char *cp)
 	*bp = '\0';		/* terminate sequence name */
     }
 
-
-    bits = FFATTRSLOT;
     for (i = 0; mp->msgattrs[i]; i++)
 	if (strcmp (mp->msgattrs[i], cp) == 0)
 	    break;
@@ -332,13 +330,12 @@ attr (struct msgs *mp, char *cp)
 
     found = 0;
     for (j = first ? first : (convdir > 0) ? mp->lowmsg : mp->hghmsg;
-		j >= mp->lowmsg && j <= mp->hghmsg; j += convdir)
+		j >= mp->lowmsg && j <= mp->hghmsg; j += convdir) {
 	if ((mp->msgstats[j] & EXISTS)
-		&& inverted ? !(mp->msgstats[j] & (1 << (bits + i)))
-		: mp->msgstats[j] & (1 << (bits + i))) {
-	    if (!(mp->msgstats[j] & SELECTED)) {
+		&& inverted ? !in_sequence (mp, i, j) : in_sequence (mp, i, j)) {
+	    if (!is_selected (mp, j)) {
+		set_selected (mp, j);
 		mp->numsel++;
-		mp->msgstats[j] |= SELECTED;
 		if (mp->lowsel == 0 || j < mp->lowsel)
 		    mp->lowsel = j;
 		if (j > mp->hghsel)
@@ -348,6 +345,7 @@ attr (struct msgs *mp, char *cp)
 	    if (range && found >= range)
 		break;		/* we've done enough */
 	}
+    }
     if (found > 0)
 	return found;
 
