@@ -1,17 +1,20 @@
 
 /*
- * m_gmsg.c -- read a folder
+ * m_gmsg.c -- read a folder and create message structure
  *
  * $Id$
  */
 
 #include <h/mh.h>
 
-/*
- * PLEASE be non-trivial...
- */
-#define	NINFO  (MAXFOLDER / 5)
+/* We allocate the `info' struct 500 at a time */
+#define	NINFO  500
 
+/*
+ * We create an array of these structures so we have
+ * a place to initially put message stats before
+ * we copy them into the message/folder structure
+ */
 struct info {
     int msgno;
     int stats;
@@ -30,18 +33,25 @@ static int m_setatr (struct msgs *, char *, char *);
 struct msgs *
 m_gmsg (char *name)
 {
-    register int i, j;
-    register struct info *rover, *tail;
-    register struct msgs *mp;
-    register struct dirent *dp;
-    DIR *dd;
+    int i, j;
+    struct info *rover, *tail;
+    struct msgs *mp;
     struct stat st;
+    struct dirent *dp;
+    DIR *dd;
 
-    if (!(dd = opendir (name = m_mailpath (name)))) {
+    name = m_mailpath (name);
+    if (!(dd = opendir (name))) {
+	free (name);
+	return NULL;
+    }
+
+/*  fstat (dd->dd_fd, &st); */
+
+    if (stat (name, &st) == -1) {
 	free (name);
 	return NULL;
     }
-    fstat (dd->dd_fd, &st);
 
     if (!(mp = (struct msgs *) malloc (MHSIZE (mp, 0, 0))))
 	adios (NULL, "unable to allocate folder storage");
@@ -87,9 +97,9 @@ m_gmsg (char *name)
 		mp->lowmsg = i;
 	    rover->msgno = i;
 	    rover->stats = EXISTS;
-#ifdef	notdef
+#if 0
 	    rover->stats &= ~DELETED;
-#endif /* notdef */
+#endif
 	    rover++;
 	}
 	else
@@ -98,7 +108,7 @@ m_gmsg (char *name)
 		    continue;
 
 		case ',': 
-#ifdef	notdef
+#if 0
 		    if ((i = m_atoi (dp->d_name + 1)) {
 			register struct info *l;
 
@@ -109,7 +119,7 @@ m_gmsg (char *name)
 				break;
 			    }
 		    }
-#endif /* notdef */
+#endif
 		    continue;
 
 #ifdef MHE
@@ -138,12 +148,12 @@ m_gmsg (char *name)
 #else /* MTR */
     mp->lowoff = mp->lowmsg;
 #endif /* MTR */
-    mp->hghoff = mp->hghmsg + 1;/* for "new" in m_convert */
+    mp->hghoff = mp->hghmsg + 1;	/* for "new" in m_convert */
 
-    mp = (struct msgs  *)
-		realloc ((char *) mp, MHSIZE (mp, mp->lowoff, mp->hghoff));
+    mp = (struct msgs *) realloc (mp, MHSIZE (mp, mp->lowoff, mp->hghoff));
     if (mp == NULL)
 	adios (NULL, "unable to allocate folder storage");
+
 #ifndef	MTR
     for (i = mp->lowmsg; i <= mp->hghmsg; i++)
 	mp->msgstats[i] = 0;
@@ -156,32 +166,37 @@ m_gmsg (char *name)
     if (mp->msgstats < (int *)0)	/* non portable */
 	adios (NULL, "m_gmsg() botch -- you lose big");
 #endif /* MTR */
-    for (tail = head; tail < rover; tail++)
-	mp->msgstats[tail->msgno] = tail->stats;
-    m_getatr (mp);
 
+    /*
+     * Interate through the array of info structures and copy
+     * the stats to the newly allocated mp->msgstats area.
+     */
+    tail = rover;
+    for (rover = head; rover < tail; rover++)
+	mp->msgstats[rover->msgno] = rover->stats;
+
+    m_getatr (mp);
     return mp;
 }
 
 static void
 m_getatr (struct msgs *mp)
 {
-    int alen, bits, i, j, plen, state;
+    int alen, i, j, plen, state;
     register char *cp;
     char name[NAMESZ], field[BUFSIZ * 2];
     register struct node *np;
     register FILE *fp;
 
-    bits = FFATTRSLOT;
-
     mp->msgattrs[i = 0] = getcpy (current);
-    mp->msgattrs[++i] = '\0';
-    mp->attrstats = 0;	/* initially, all public */
+    mp->msgattrs[++i] = NULL;
+    make_all_public (mp);	/* initially, all public */
 
     m_getdefs ();
     if (mh_seq == '\0' || *mh_seq == '\0')
 	goto private_only;
 
+    /* read folder's sequences file */
     sprintf (field, "%s/%s", mp->foldpath, mh_seq);
     if ((fp = fopen (field, "r"))) {
 	for (state = FLD;;) {
@@ -195,15 +210,15 @@ m_getatr (struct msgs *mp)
 
 		case BODY: 
 		case BODYEOF: 
-		    adios (NULL,
-			    "no blank lines are permitted in %s/%s",
-			    mp->foldpath, mh_seq);/* fall */
+		    adios (NULL, "no blank lines are permitted in %s/%s",
+			   mp->foldpath, mh_seq);	/* fall */
 
 		case FILEEOF:
 		    break;
 
 		default: 
-		    adios (NULL, "%s/%s is poorly formatted", mp->foldpath, mh_seq);
+		    adios (NULL, "%s/%s is poorly formatted",
+			   mp->foldpath, mh_seq);
 	    }
 	    break;
 	}
@@ -222,56 +237,71 @@ private_only: ;
 	    cp = getcpy (np->n_name + alen);
 	    *(cp + j - alen) = '\0';
 	    if ((i = m_setatr (mp, cp, getcpy (np->n_field))) != NOTOK)
-		mp->attrstats |= 1 << (bits + i);/* private */
+		make_seq_private (mp, i);
 	}
 }
 
 static int
 m_setatr (struct msgs *mp, char *name, char *field)
 {
-    int bits, hack;
+    int hack;
     register int i, j, k;
     register char *cp, **ap;
 
-    bits = FFATTRSLOT;
-    hack = strcmp (current, name) == 0;/* hack... */
+    hack = strcmp (current, name) == 0;	/* hack... */
     /* if we're going to use UNSEEN, it should be set here! */
 
-    for (i = 0; mp->msgattrs[i]; i++)
+    /*
+     * If we've seen this sequence before, then
+     * clear the bit for this sequence from
+     * all the mesages in this folder.
+     */
+    for (i = 0; mp->msgattrs[i]; i++) {
 	if (strcmp (mp->msgattrs[i], name) == 0) {
 	    for (j = mp->lowmsg; j <= mp->hghmsg; j++)
-		mp->msgstats[j] &= ~(1 << (bits + i));
+		clear_sequence (mp, i, j);
 	    break;
 	}
+    }
+
     if (i >= NUMATTRS) {
 	free (name);
 	free (field);
 	return NOTOK;
     }
 
-    if (!mp->msgattrs[i]) {
+    if (mp->msgattrs[i]) {
+	free (name);
+    } else {
 	mp->msgattrs[i] = name;
 	mp->msgattrs[i + 1] = NULL;
     }
-    else
-	free (name);
 
+    /*
+     * split up the different message ranges at whitespace
+     */
     for (ap = brkstring (field, " ", "\n"); *ap; ap++) {
 	if ((cp = strchr(*ap, '-')))
 	    *cp++ = '\0';
 	if ((j = m_atoi (*ap)) > 0) {
-#ifdef	notdef
+	    k = cp ? m_atoi (cp) : j;
+#if 0
 	    if (hack && j >= mp->lowmsg && j <= mp->hghmsg
 		    && (mp->msgstats[j] & EXISTS))
 		mp->curmsg = j;
-#else /* not notdef */
+#else
 	    if (hack)
 		mp->curmsg = j;
-#endif /* not notdef */
-	    for (k = cp ? m_atoi (cp) : j; j <= k; j++)
+#endif
+	    /*
+	     * We iterate through messages in this range
+	     * and flip on bit for this sequence.
+	     */
+	    for (; j <= k; j++) {
 		if (j >= mp->lowmsg && j <= mp->hghmsg
 			&& (mp->msgstats[j] & EXISTS))
-		    mp->msgstats[j] |= 1 << (bits + i);
+		    add_sequence (mp, i, j);
+	    }
 	}
     }
     free (field);
