@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 #define	CWD	"./"
 #define	NCWD	(sizeof CWD - 1)
@@ -42,16 +42,16 @@ m_mailpath (char *folder)
     register char *cp;
     char maildir[BUFSIZ];
 
-    if (*folder == '/'
-	    || strncmp (folder, CWD, NCWD) == 0
-	    || strcmp (folder, DOT) == 0
-	    || strcmp (folder, DOTDOT) == 0
-	    || strncmp (folder, PWD, NPWD) == 0)
-	cp = path (folder, TFOLDER);
-    else {
-	strcpy (maildir, mailfold);/* preserve... */
+    if (*folder != '/'
+	    && strncmp (folder, CWD, NCWD)
+	    && strcmp (folder, DOT)
+	    && strcmp (folder, DOTDOT)
+	    && strncmp (folder, PWD, NPWD)) {
+	strcpy (maildir, mailfold);		/* preserve... */
 	cp = getcpy (m_maildir (folder));
 	strcpy (mailfold, maildir);
+    } else {
+	cp = path (folder, TFOLDER);
     }
 
     return cp;
@@ -67,17 +67,17 @@ exmaildir (char *folder)
     if (folder == NULL)
 	folder = m_getfolder();
 
-    if (*folder == '/'
-	    || strncmp (folder, CWD, NCWD) == 0
-	    || strcmp (folder, DOT) == 0
-	    || strcmp (folder, DOTDOT) == 0
-	    || strncmp (folder, PWD, NPWD) == 0) {
+    if (!(*folder != '/'
+	    && strncmp (folder, CWD, NCWD)
+	    && strcmp (folder, DOT)
+	    && strcmp (folder, DOTDOT)
+	    && strncmp (folder, PWD, NPWD))) {
 	strcpy (mailfold, folder);
 	return mailfold;
     }
 
     cp = mailfold;
-    if ((pp = m_find ("path")) != NULL && *pp) {
+    if ((pp = m_find ("path")) && *pp) {
 	if (*pp != '/') {
 	    sprintf (cp, "%s/", mypath);
 	    cp += strlen (cp);
