@@ -1,6 +1,7 @@
 
 /*
- * m_readefs.c -- read a profile/context file
+ * m_readefs.c -- read a nmh configuration files
+ *             -- (profile/context/mhn.defaults)
  *
  * $Id$
  */
@@ -22,6 +23,7 @@ static struct procstr procs[] = {
     { "lproc",        &lproc },
     { "mailproc",     &mailproc },
     { "mhlproc",      &mhlproc },
+    { "mhnproc",      &mhnproc },
     { "moreproc",     &moreproc },
     { "mshproc",      &mshproc },
     { "packproc",     &packproc },
