@@ -5,13 +5,13 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 
 char *
 m_scratch (char *file, char *template)
 {
-    register char  *cp;
+    register char *cp;
     static char buffer[BUFSIZ], tmpfil[BUFSIZ];
 
     sprintf (tmpfil, "%sXXXXXX", template);
