@@ -1,6 +1,7 @@
 
 /*
- * m_seq.c -- print out a message sequence
+ * m_seq.c -- get all messages in a sequence and return them
+ *         -- as a space separated list of message ranges
  *
  * $Id$
  */
@@ -9,16 +10,18 @@
 
 
 char *
-m_seq(struct msgs *mp, char *cp)
+m_seq(struct msgs *mp, char *seqname)
 {
 	int mask;
 	register int i, j;
 	register char *bp;
 	static char buffer[BUFSIZ*2];	/* for big sequences */
 
-	if (!strcmp (current, cp)) {
-	    /* assume this is in sync with msgstats["cur"] */
-	    /* see m_seqadd() for details */
+	/*
+	 * assume this is in sync with msgstats["cur"]
+	 * see m_seqadd() for details
+	 */
+	if (!strcmp (current, seqname)) {
 	    if (mp->curmsg) {	
 		sprintf(buffer, "%s", m_name(mp->curmsg));
 		return (buffer);
@@ -26,7 +29,7 @@ m_seq(struct msgs *mp, char *cp)
 		return (NULL);
 	}
 	for (i = 0; mp->msgattrs[i]; i++)
-		if (!strcmp(mp->msgattrs[i], cp))
+		if (!strcmp(mp->msgattrs[i], seqname))
 			break;
 	
 	if (!mp->msgattrs[i])
