@@ -24,7 +24,7 @@ makedir (char *dir)
     register char *c;
     char path[PATH_MAX];
 
-    m_update();
+    m_update();		/* update the context file */
     fflush(stdout);
 
     if (getuid () == geteuid ()) {
