@@ -5,8 +5,12 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "sigmsg.h"
+#include <h/mh.h>
+
+/*
+ * generated header
+ */
+#include <sigmsg.h>
 
 #ifdef HAVE_SYS_WAIT_H
 # include <sys/wait.h>
