@@ -21,12 +21,6 @@
 #include <pwd.h>
 #include <errno.h>
 
-char *malloc();
-char *getenv();
-char *getpass();
-char *getlogin();
-char *strcpy();
-
 static FILE *cfile;
 
 #ifndef MAXHOSTNAMELEN
@@ -41,7 +35,6 @@ static FILE *cfile;
 #define	ID	10
 #define	MACH	11
 
-static int token();
 static char tokval[100];
 
 struct toktab {
@@ -60,6 +53,12 @@ static struct toktab toktabs[] = {
     { 0,          0 }
 };
 
+/*
+ * prototypes
+ */
+static int token(void);
+
+
 int
 ruserpass(char *host, char **aname, char **apass)
 {
