@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 
 char *
@@ -15,12 +15,12 @@ sprintb (char *buffer, unsigned v, char *bits)
     register char c, *bp;
 
     sprintf (buffer, bits && *bits == 010 ? "0%o" : "0x%x", v);
-    bp = buffer + strlen (buffer);
+    bp = buffer + strlen(buffer);
 
     if (bits && *++bits) {
 	j = 0;
 	*bp++ = '<';
-	while (i = *bits++)
+	while ((i = *bits++))
 	    if (v & (1 << (i - 1))) {
 		if (j++)
 		    *bp++ = ',';
