@@ -124,11 +124,15 @@ main (int argc, char **argv)
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
+
+    /* read folder and create message structure */
     if (!(mp = m_gmsg (folder)))
 	adios (NULL, "unable to read folder %s", folder);
+
     if (mp->hghmsg == 0)
 	adios (NULL, "no messages in %s", folder);
 
+    /* parse all the message ranges/sequences and set SELECTED */
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
@@ -136,15 +140,15 @@ main (int argc, char **argv)
     make_comp (&comp);
 
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	if (mp->msgstats[msgnum] & SELECTED)
+	if (is_selected(mp, msgnum))
 	    annotate (m_name (msgnum), comp, text, inplace, datesw);
 
-    m_replace (pfolder, folder);
+    m_replace (pfolder, folder);	/* update current folder */
     if (mp->lowsel != mp->curmsg)
 	m_setcur (mp, mp->lowsel);
     m_sync (mp);
-    m_update ();
-
+    m_fmsg (mp);	/* free folder/message structure */
+    m_update ();	/* update the context file       */
     done (0);
 }
 
