@@ -122,29 +122,33 @@ main (int argc, char **argv)
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
+
+    /* read folder and create message structure */
     if (!(mp = m_gmsg (folder)))
 	adios (NULL, "unable to read folder %s", folder);
+
     if (mp->hghmsg == 0)
 	adios (NULL, "no messages in %s", folder);
 
+    /* parse all the message ranges/sequences and set SELECTED */
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
-    m_setseq (mp);
+    m_setseq (mp);	/* set the previous-sequence */
 
-    smsgs = (struct smsg   *)
-		calloc ((unsigned) (MAXFOLDER + 2), sizeof *smsgs);
+    smsgs = (struct smsg *)
+		calloc ((size_t) (MAXFOLDER + 2), sizeof *smsgs);
     if (smsgs == NULL)
 	adios (NULL, "unable to allocate burst storage");
 
     hi = mp->hghmsg + 1;
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	if (mp->msgstats[msgnum] & SELECTED)
+	if (is_selected (mp, msgnum))
 	    burst (smsgs, msgnum, inplace, quietsw, verbosw);
 
     free ((char *) smsgs);
 
-    m_replace (pfolder, folder);
+    m_replace (pfolder, folder);	/* update current folder */
     if (inplace) {
 	if (mp->lowsel != mp->curmsg)
 	    m_setcur (mp, mp->lowsel);
@@ -152,9 +156,10 @@ main (int argc, char **argv)
     else
 	if (hi <= mp->hghmsg)
 	    m_setcur (mp, hi);
-    m_sync (mp);
-    m_update ();
 
+    m_sync (mp);
+    m_fmsg (mp);	/* free folder/message structure */
+    m_update ();	/* update the context file       */
     done (0);
 }
 
@@ -253,7 +258,7 @@ burst (struct smsg *smsgs, int msgnum, int inplace, int quietsw, int verbosw)
 	    }
 	}
     
-    mp->msgstats[msgnum] &= ~SELECTED;
+    unset_selected (mp, msgnum);
     i = inplace ? msgnum + msgp : mp->hghmsg; /* new hghmsg is hghmsg+msgp */
     for (j = msgp; j >= (inplace ? 0 : 1); i--, j--) {
 	strcpy (f1, m_name (i));
