@@ -192,31 +192,34 @@ main (int argc, char **argv)
 
 	if (chdir (maildir) == NOTOK)
 	    adios (maildir, "unable to change directory to");
+
+	/* read folder and create message structure */
 	if (!(mp = m_gmsg (folder)))
 	    adios (NULL, "unable to read folder %s", folder);
+
 	if (mp->hghmsg == 0)
 	    adios (NULL, "no messages in %s", folder);
 
+	/* parse the message range/sequence/name and set SELECTED */
 	if (!m_convert (mp, msg))
 	    done (1);
-	m_setseq (mp);
+	m_setseq (mp);	/* set the previous-sequence */
 
 	if (mp->numsel > 1)
 	    adios (NULL, "only one message at a time!");
 
 	if ((in = open (form = getcpy (m_name (mp->lowsel)), 0)) == NOTOK)
 	    adios (form, "unable to open message");
-    }
-    else
+    } else {
 	if (form) {
 	    if ((in = open (etcpath (form), 0)) == NOTOK)
 		adios (form, "unable to open form file");
-	}
-	else {
+	} else {
 	    if ((in = open (etcpath (components), 0)) == NOTOK)
 		adios (components, "unable to open default components file");
 	    form = components;
 	}
+    }
 
 try_it_again: ;
     strcpy (drft, m_draft (dfolder, file, use, &isdf));
@@ -268,7 +271,7 @@ try_it_again: ;
     close (out);
 
 edit_it: ;
-    m_update ();
+    m_update ();	/* update the context file */
 
     if (nwhat)
 	done (0);
