@@ -5,28 +5,26 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/formatsbr.h"
-#include "../h/fmtcompile.h"
-#include "../h/scansbr.h"
+#include <h/mh.h>
+#include <h/formatsbr.h>
+#include <h/fmtcompile.h>
+#include <h/scansbr.h>
 
 static struct swit switches[] = {
-#define	FORMSW	0
-    "form formatfile", 0,
-#define	FMTSW	1
-    "format string", 5,
-
-#define VERSIONSW 2
-    "version", 0,
-#define	HELPSW	3
-    "help", 4,
-
-    NULL, 0
+#define	FORMSW              0
+    { "form formatfile", 0 },
+#define	FMTSW               1
+    { "format string", 5 },
+#define VERSIONSW           2
+    { "version", 0 },
+#define	HELPSW              3
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 /* for assignlabel */
-static 	struct format *lvec[128];
-static 	lused = 0;
+static struct format *lvec[128];
+static lused = 0;
 
 /*
  * static prototypes
@@ -43,15 +41,10 @@ static void litputc(char);
 
 main (int argc, char **argv)
 {
-    int    ncomps;
-    char   *cp,
-	   *form = NULL,
-	   *format = NULL,
-            buf[100],
-          **ap,
-          **argp,
-           *nfs,
-           *arguments[MAXARGS];
+    int ncomps;
+    char *cp, *form = NULL, *format = NULL;
+    char buf[100], **ap, **argp;
+    char *nfs, *arguments[MAXARGS];
     struct format *fmt;
 
 #ifdef LOCALE
@@ -67,7 +60,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
