@@ -1,6 +1,6 @@
 
 /*
- * mhlsbr.c -- implement the "nifty" message lister
+ * mhlsbr.c -- main routines for nmh message lister
  *
  * $Id$
  */
@@ -88,24 +88,24 @@ static struct swit mhlswitches[] = {
     { NULL, 0 }
 };
 
-#define NOCOMPONENT	0x000001/* don't show component name            */
-#define UPPERCASE       0x000002/* display in all upper case            */
-#define CENTER          0x000004/* center line				*/
-#define CLEARTEXT       0x000008/* cleartext				*/
-#define EXTRA		0x000010/* an "extra" component			*/
-#define HDROUTPUT	0x000020/* already output			*/
-#define CLEARSCR	0x000040/* clear screen				*/
-#define LEFTADJUST	0x000080/* left justify multiple lines		*/
-#define COMPRESS	0x000100/* compress text			*/
-#define	ADDRFMT		0x000200/* contains addresses			*/
-#define	BELL		0x000400/* sound bell at EOP			*/
-#define	DATEFMT		0x000800/* contains dates			*/
-#define	FORMAT		0x001000/* parse address/date			*/
-#define	INIT		0x002000/* initialize component			*/
-#define	FACEFMT		0x004000/* contains face			*/
-#define	FACEDFLT	0x008000/* default for face			*/
-#define	SPLIT		0x010000/* split headers (don't concatenate)	*/
-#define	NONEWLINE	0x020000/* don't write trailing newline		*/
+#define NOCOMPONENT 0x000001	/* don't show component name         */
+#define UPPERCASE   0x000002	/* display in all upper case         */
+#define CENTER      0x000004	/* center line                       */
+#define CLEARTEXT   0x000008	/* cleartext                         */
+#define EXTRA       0x000010	/* an "extra" component              */
+#define HDROUTPUT   0x000020	/* already output                    */
+#define CLEARSCR    0x000040	/* clear screen                      */
+#define LEFTADJUST  0x000080	/* left justify multiple lines       */
+#define COMPRESS    0x000100	/* compress text                     */
+#define	ADDRFMT     0x000200	/* contains addresses                */
+#define	BELL        0x000400	/* sound bell at EOP                 */
+#define	DATEFMT     0x000800	/* contains dates                    */
+#define	FORMAT      0x001000	/* parse address/date                */
+#define	INIT        0x002000	/* initialize component              */
+#define	FACEFMT     0x004000	/* contains face                     */
+#define	FACEDFLT    0x008000	/* default for face                  */
+#define	SPLIT       0x010000	/* split headers (don't concatenate) */
+#define	NONEWLINE   0x020000	/* don't write trailing newline      */
 #define	LBITS	"\020\01NOCOMPONENT\02UPPERCASE\03CENTER\04CLEARTEXT\05EXTRA\06HDROUTPUT\07CLEARSCR\010LEFTADJUST\011COMPRESS\012ADDRFMT\013BELL\014DATEFMT\015FORMAT\016INIT\017FACEFMT\020FACEDFLT\021SPLIT\022NONEWLINE"
 #define	GFLAGS	(NOCOMPONENT | UPPERCASE | CENTER | LEFTADJUST | COMPRESS | SPLIT)
 
@@ -1017,7 +1017,7 @@ mcomp_format (struct mcomp *c1, struct mcomp *c2)
 
     (q = &pq)->pq_next = NULL;
     while (cp = getname (ap)) {
-	if ((p = (struct pqpair *) calloc ((unsigned) 1, sizeof *p)) == NULL)
+	if ((p = (struct pqpair *) calloc ((size_t) 1, sizeof *p)) == NULL)
 	    adios (NULL, "unable to allocate pqpair memory");
 
 	if ((mp = getm (cp, NULL, 0, AD_NAME, error)) == NULL) {
@@ -1074,7 +1074,7 @@ add_queue (struct mcomp **head, struct mcomp **tail, char *name, char *text, int
 {
     register struct mcomp *c1;
 
-    if ((c1 = (struct mcomp *) calloc ((unsigned) 1, sizeof *c1)) == NULL)
+    if ((c1 = (struct mcomp *) calloc ((size_t) 1, sizeof *c1)) == NULL)
 	adios (NULL, "unable to allocate comp memory");
 
     c1->c_flags = flags & ~INIT;
