@@ -44,15 +44,15 @@ main (int argc, char **argv)
     int status, i, iscc = 0, nvec;
     int queued = 0, resent = 0, somebody;
     char *cp, *tolist = NULL, *cclist = NULL, *subject = NULL;
-    char *from = NULL, *body = NULL, **argp = argv + 1, buf[100];
-    char *vec[5];
+    char *from = NULL, *body = NULL, **argp = argv + 1;
+    char *vec[5], buf[BUFSIZ];
     FILE *out;
 
 #ifdef LOCALE
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    m_foil (NULL);
+    m_foil (NULL);	/* foil search of user profile */
 
     if (argc == 1) {
 	execlp (incproc, r1bindex (incproc, '/'), NULL);
@@ -132,12 +132,11 @@ main (int argc, char **argv)
 	fprintf (out, "%s", body);
 	if (*body && *(body + strlen (body) - 1) != '\n')
 	    fputs ("\n", out);
-    }
-    else {
+    } else {
 	for (somebody = 0;
-		(i = fread (buf, sizeof *buf, sizeof buf, stdin)) > 0;
+		(i = fread (buf, sizeof(*buf), sizeof(buf), stdin)) > 0;
 		somebody++)
-	    if (fwrite (buf, sizeof *buf, i, out) != i)
+	    if (fwrite (buf, sizeof(*buf), i, out) != i)
 		adios (tmpfil, "error writing");
 	if (!somebody) {
 	    unlink (tmpfil);
