@@ -15,12 +15,19 @@ static struct swit switches[] = {
     { NULL, 0 }
 };
 
+/*
+ * Add space for message/sequence names
+ * by NUMMSGS at a time.
+ */
+#define NUMMSGS 512
+
 
 main(int argc, char **argv)
 {
-    int msgp = 0, i;
-    char *cp, *maildir, *folder = NULL, buf[100];
-    char **ap, **argp, *arguments[MAXARGS], *msgs[MAXARGS];
+    int i, maxmsgs, msgp = 0;
+    char *cp, *maildir, *folder = NULL;
+    char **ap, **argp, **msgs;
+    char *arguments[MAXARGS], buf[100];
     struct msgs *mp;
 
 #ifdef LOCALE
@@ -30,12 +37,17 @@ main(int argc, char **argv)
     if ((cp = m_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
+    /* Allocate initial space to record message/sequence names */
+    maxmsgs = NUMMSGS;
+    if ((msgs = malloc (maxmsgs * sizeof(char *))) == NULL)
+	adios (NULL, "unable to allocate storage for message/sequence names");
+
     while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
@@ -58,9 +70,15 @@ main(int argc, char **argv)
 		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	}
-	else
+	} else {
+	    /* if necessary, reallocate space for message/sequence names */
+	    if (msgp >= maxmsgs) {
+		maxmsgs += NUMMSGS;
+		if ((msgs = realloc (msgs, maxmsgs * sizeof(char *))) == NULL)
+		    adios (NULL, "unable to re-allocate storage for message names");
+	    }
 	    msgs[msgp++] = cp;
+	}
     }
 
     if (!m_find ("path"))
@@ -95,14 +113,12 @@ main(int argc, char **argv)
 
     m_setseq (mp);	/* set the previous-sequence */
 
-    if (mp->numsel > MAXARGS - 2)
-	adios (NULL, "more than %d messages", MAXARGS - 2);
-
+    /* print the path of all selected messages */
     for (i = mp->lowsel; i <= mp->hghsel; i++)
 	if (is_selected (mp, i))
 	    printf ("%s/%s\n", mp->foldpath, m_name (i));
 
-    m_sync (mp);
+    m_sync (mp);	/* synchronize message sequences */
     m_fmsg (mp);	/* free folder/message structure */
     m_update ();	/* update the context file       */
     done (0);
