@@ -1058,7 +1058,7 @@ check_folder (int scansw)
 	mtime = st.st_mtime;
 
 	low = mp->hghmsg + 1;
-	m_fmsg (mp);
+	m_fmsg (mp);		/* free folder/message info */
 
 	if (!(mp = m_gmsg (fmsh)))
 	    padios (NULL, "unable to re-read folder %s", fmsh);
@@ -1427,7 +1427,11 @@ getargs (char *prompt, struct swit *sw, struct Cmd *cmdp)
 		    continue;
 		}
 		if (ppid > 0)
+#ifdef SIGEMT
 		    kill (ppid, SIGEMT);
+#else
+		    kill (ppid, SIGTERM);
+#endif
 		return EOF;
 	}
 #endif /* BSD42 */
@@ -1444,7 +1448,11 @@ getargs (char *prompt, struct swit *sw, struct Cmd *cmdp)
 	    }
 	    if (told_to_quit || i == EOF) {
 		if (ppid > 0)
+#ifdef SIGEMT
 		    kill (ppid, SIGEMT);
+#else
+		    kill (ppid, SIGTERM);
+#endif
 		return EOF;
 	    }
 #else /* BSD42 */
@@ -1509,7 +1517,11 @@ getcmds (struct swit *sw, struct Cmd *cmdp, int scansw)
 
 	    case RC_FIN: 
 		if (ppid > 0)
+#ifdef SIGEMT
 		    kill (ppid, SIGEMT);
+#else
+		    kill (ppid, SIGTERM);
+#endif
 		return EOF;
 
 	    case RC_XXX: 
@@ -1768,7 +1780,7 @@ m_init (void)
     int msgnum;
 
     for (msgnum = mp->lowmsg; msgnum <= mp->hghmsg; msgnum++)
-	mp->msgstats[msgnum] &= ~SELECTED;
+	unset_selected (mp, msgnum);
     mp->lowsel = mp->hghsel = mp->numsel = 0;
 }
 
@@ -1777,7 +1789,7 @@ void
 m_reset (void)
 {
     write_ids ();
-    m_fmsg (mp);
+    m_fmsg (mp);	/* free folder/message info */
     myname = NULL;
 #ifdef	BPOP
     if (pmsh) {
