@@ -81,9 +81,9 @@ forkcmd (char **args, char *pgm)
 
     if (fmsh) {
 	m_delete (pfolder);
-	m_replace (pfolder, fmsh);
+	m_replace (pfolder, fmsh);	/* update current folder   */
 	m_sync (mp);
-	m_update ();
+	m_update ();			/* update the context file */
     }
     fflush (stdout);
     switch (child_id = fork ()) {
@@ -306,7 +306,7 @@ explcmd (char **args)
     m_setseq (mp);
 
     smsgs = (struct Msg *)
-		calloc ((unsigned) (MAXFOLDER + 2), sizeof *smsgs);
+		calloc ((size_t) (MAXFOLDER + 2), sizeof *smsgs);
     if (smsgs == NULL)
 	adios (NULL, "unable to allocate folder storage");
 
@@ -315,7 +315,7 @@ explcmd (char **args)
     for (msgnum = mp->lowsel;
 	    msgnum <= mp->hghsel && !interrupted;
 	    msgnum++)
-	if (mp->msgstats[msgnum] & SELECTED)
+	if (is_selected (mp, msgnum))
 	    if (burst (smsgs, msgnum, inplace, quietsw, verbosw) != OK)
 		break;
 
@@ -429,7 +429,7 @@ burst (struct Msg *smsgs, int msgnum, int inplace, int quietsw, int verbosw)
     if (Msgs[msgnum].m_bboard_id == 0)
 	readid (msgnum);
 
-    mp->msgstats[msgnum] &= ~SELECTED;
+    unset_selected (mp, msgnum);
     i = inplace ? msgnum + msgp : mp->hghmsg;
     for (j = msgp; j >= (inplace ? 0 : 1); i--, j--) {
 	if (verbosw && i != msgnum)
@@ -539,9 +539,9 @@ filecmd (char **args)
     for (msgnum = mp->lowsel;
 	    msgnum <= mp->hghsel && !interrupted;
 	    msgnum++)
-	if (mp->msgstats[msgnum] & SELECTED)
+	if (is_selected (mp, msgnum))
 	    if (process (msgnum, fileproc, vecp, vec)) {
-		mp->msgstats[msgnum] &= ~SELECTED;
+		unset_selected (mp, msgnum);
 		mp->numsel--;
 	    }
 
@@ -990,7 +990,7 @@ forw (char *proc, char *filter, int vecp, char **vec)
 		args[i++] = "-form";
 		args[i++] = filter;
 		for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-		    if (mp->msgstats[msgnum] & SELECTED)
+		    if (is_selected (mp, msgnum))
 			args[i++] = getcpy (m_name (msgnum));
 		args[i] = NULL;
 		mhlsbr (i, args, mhl_action);
@@ -1013,7 +1013,7 @@ forw (char *proc, char *filter, int vecp, char **vec)
 	for (msgnum = mp->lowsel;
 		msgnum <= mp->hghsel && !interrupted;
 		msgnum++)
-	    if (mp->msgstats[msgnum] & SELECTED) {
+	    if (is_selected (mp, msgnum)) {
 		fprintf (out, "\n\n-------");
 		if (msgnum == mp->lowsel)
 		    fprintf (out, " Forwarded Message%s",
@@ -1244,7 +1244,7 @@ markcmd (char **args)
 	    if (zerosw && !m_seqnew (mp, seqs[seqp], 0))
 		return;
 	    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-		if (mp->msgstats[msgnum] & SELECTED)
+		if (is_selected (mp, msgnum))
 		    if (!m_seqadd (mp, seqs[seqp], msgnum, 0))
 			return;
 	}
@@ -1257,21 +1257,18 @@ markcmd (char **args)
 			if (!m_seqadd (mp, seqs[seqp], msgnum, 0))
 			    return;
 	    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-		if (mp->msgstats[msgnum] & SELECTED)
+		if (is_selected (mp, msgnum))
 		    if (!m_seqdel (mp, seqs[seqp], msgnum))
 			return;
 	}
 
-    if (listsw) {
-	int bits = FFATTRSLOT;
-
 #define empty(s) ((s) ? (s) : "")
 
+    if (listsw) {
 	if (!seqp) {
 	    for (i = 0; mp->msgattrs[i]; i++)
 		printf ("%s%s: %s\n", mp->msgattrs[i],
-			mp->attrstats & (1 << (bits + i))
-			? " (private)" : "",
+			is_seq_private (mp, i) ? " (private)" : "",
 			empty(m_seq (mp, mp->msgattrs[i])));
 	} else {
 	    for (seqp = 0; seqs[seqp]; seqp++)
@@ -1285,7 +1282,7 @@ markcmd (char **args)
 	    for (msgnum = mp->lowsel;
 		    msgnum <= mp->hghsel && !interrupted;
 		    msgnum++)
-		if (mp->msgstats[msgnum] & SELECTED) {
+		if (is_selected (mp, msgnum)) {
 		    printf ("%*d: id=%d top=%d start=%ld stop=%ld %s\n",
 			    DMAXFOLDER, msgnum,
 			    Msgs[msgnum].m_bboard_id, Msgs[msgnum].m_top,
@@ -1451,9 +1448,9 @@ mhncmd (char **args)
     for (msgnum = mp->lowsel;
 	    msgnum <= mp->hghsel && !interrupted;
 	    msgnum++)
-	if (mp->msgstats[msgnum] & SELECTED)
+	if (is_selected (mp, msgnum))
 	    if (process (msgnum, cmd_name, vecp, vec)) {
-		mp->msgstats[msgnum] &= ~SELECTED;
+		unset_selected (mp, msgnum);
 		mp->numsel--;
 	    }
 
@@ -1540,7 +1537,7 @@ packcmd (char **args)
 	goto done_pack;
     }
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	if (mp->msgstats[msgnum] & SELECTED)
+	if (is_selected (mp, msgnum))
 	    if (pack (file, md, msgnum) == NOTOK)
 		break;
     mbx_close (file, md);
@@ -1756,7 +1753,7 @@ pattern: ;
     for (msgnum = mp->lowsel;
 	    msgnum <= mp->hghsel && !interrupted;
 	    msgnum++)
-	if (mp->msgstats[msgnum] & SELECTED) {
+	if (is_selected (mp, msgnum)) {
 	    zp = msh_ready (msgnum, 1);
 	    if (pmatches (zp, msgnum, fmsh ? 0L : Msgs[msgnum].m_start,
 			fmsh ? 0L : Msgs[msgnum].m_stop)) {
@@ -1766,7 +1763,7 @@ pattern: ;
 		    hi = msgnum;
 	    }
 	    else {
-		mp->msgstats[msgnum] &= ~SELECTED;
+		unset_selected (mp, msgnum);
 		mp->numsel--;
 	    }
 	}
@@ -1787,7 +1784,7 @@ pattern: ;
 	if (zerosw && !m_seqnew (mp, seqs[seqp], 0))
 	    return;
 	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	    if (mp->msgstats[msgnum] & SELECTED)
+	    if (is_selected (mp, msgnum))
 		if (!m_seqadd (mp, seqs[seqp], msgnum, 0))
 		    return;
     }
@@ -1992,7 +1989,7 @@ rmm (void)
 	    }
 	    vecp = 0;
 	    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-		if (mp->msgstats[msgnum] & SELECTED)
+		if (is_selected (mp, msgnum))
 		    vec[vecp++] = getcpy (m_name (msgnum));
 	    vec[vecp] = NULL;
 	    forkcmd (vec, rmmproc);
@@ -2001,7 +1998,7 @@ rmm (void)
 	}
 	else
 	    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-		if (mp->msgstats[msgnum] & SELECTED) {
+		if (is_selected (mp, msgnum)) {
 		    strcpy (buffer, m_backup (cp = m_name (msgnum)));
 		    if (rename (cp, buffer) == NOTOK)
 			admonish (buffer, "unable to rename %s to", cp);
@@ -2009,7 +2006,7 @@ rmm (void)
     }
 
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	if (mp->msgstats[msgnum] & SELECTED) {
+	if (is_selected (mp, msgnum)) {
 	    mp->msgstats[msgnum] |= DELETED;
 	    mp->msgstats[msgnum] &= ~EXISTS;
 #ifdef	MPOP
@@ -2201,7 +2198,7 @@ scancmd (char **args)
 #ifdef	BPOP
     if (p_optim && optim) {
 	for (msgnum = mp->lowmsg; msgnum <= mp->hghmsg; msgnum++)
-	    if (!(mp->msgstats[msgnum] & SELECTED) || Msgs[msgnum].m_scanl)
+	    if (!is_selected(mp, msgnum) || Msgs[msgnum].m_scanl)
 		break;
 	if (msgnum > mp->hghmsg && pop_command ("LIST") == OK) {
 	    fprintf (stderr, "Stand-by...");
@@ -2238,7 +2235,7 @@ scancmd (char **args)
     for (msgnum = mp->lowsel;
 	    msgnum <= mp->hghsel && !interrupted;
 	    msgnum++)
-	if (mp->msgstats[msgnum] & SELECTED) {
+	if (is_selected (mp, msgnum)) {
 	    if (optim && Msgs[msgnum].m_scanl)
 		printf ("%s", Msgs[msgnum].m_scanl);
 	    else {
@@ -2260,7 +2257,7 @@ scancmd (char **args)
 		zp = msh_ready (msgnum, 0);
 		switch (state = scan (zp, msgnum, 0, nfs, width,
 			msgnum == mp->curmsg,
-			mp->msgstats[msgnum] & UNSEEN,	/* ?? */
+			is_unseen (mp, msgnum),
 			headersw ? (fmsh ? fmsh : mp->foldpath) : (char *)0,
 			fmsh ? 0L : (long) (Msgs[msgnum].m_stop - Msgs[msgnum].m_start),
 			1)) {
@@ -2399,20 +2396,20 @@ showcmd (char **args)
 	    return;
     m_setseq (mp);
 
-#ifdef	MIME
+#ifdef MIME
     if (!nshow && !getenv ("NOMHNPROC"))
 	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	    if ((mp->msgstats[msgnum] & SELECTED) && nontext (msgnum)) {
-		proc = (cp = m_find ("mhnproc")) ? cp : "mhn";
+	    if (is_selected (mp, msgnum) && nontext (msgnum)) {
+		proc = mhnproc;
 		vec[vecp++] = "-show";
 		vec[vecp++] = "-file";
 		vec[vecp] = NULL;
 		goto finish;
 	    }
-#endif	/* MIME */
+#endif /* MIME */
 
     if (nshow)
-	proc = "cat";
+	proc = catproc;
     else
 	if (strcmp (showproc, "mhl") == 0) {
 	    proc = mhlproc;
@@ -2425,7 +2422,7 @@ finish: ;
     if (mhl) {
 	msgp = vecp;
 	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	    if (mp->msgstats[msgnum] & SELECTED) {
+	    if (is_selected (mp, msgnum)) {
 		vec[vecp++] = getcpy (m_name (msgnum));
 		if (seen)
 		    m_seqdel (mp, "unseen", msgnum);
@@ -2443,7 +2440,7 @@ finish: ;
 	for (msgnum = mp->lowsel;
 		msgnum <= mp->hghsel && !interrupted;
 		msgnum++)
-	    if (mp->msgstats[msgnum] & SELECTED) {
+	    if (is_selected (mp, msgnum)) {
 		switch (ask (msgnum)) {
 		    case NOTOK: /* QUIT */
 			break;
@@ -2824,7 +2821,7 @@ sortcmd (char **args)
 	    free (Msgs[msgnum].m_scanl);
 	    Msgs[msgnum].m_scanl = NULL;
 	}
-	if (mp->msgstats[msgnum] & SELECTED) {
+	if (is_selected (mp, msgnum)) {
 	    if (getws (datesw, subjsw, msgnum, &Msgs[msgnum]))
 		twscopy (&Msgs[msgnum].m_tb,
 			msgnum != mp->lowsel ? &Msgs[msgnum - 1].m_tb : &tb);
@@ -3004,9 +3001,9 @@ process (int msgnum, char *proc, int vecp, char **vec)
     if (fmsh) {
 	strcpy (tmpfil, m_name (msgnum));
 	m_delete (pfolder);
-	m_replace (pfolder, fmsh);
+	m_replace (pfolder, fmsh);	/* update current folder   */
 	m_sync (mp);
-	m_update ();
+	m_update ();			/* update the context file */
 	goto ready;
     }
 
