@@ -184,15 +184,19 @@ main (int argc, char **argv)
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
+
+    /* read folder and create message structure */
     if (!(mp = m_gmsg (folder)))
 	adios (NULL, "unable to read folder %s", folder);
+
     if (mp->hghmsg == 0)
 	adios (NULL, "no messages in %s", folder);
 
+    /* parse all the message ranges/sequences and set SELECTED */
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
-    m_setseq (mp);
+    m_setseq (mp);	/* set the previous-sequence */
 
     if (seqp == 0)
 	listsw++;
@@ -209,7 +213,7 @@ main (int argc, char **argv)
     hi = mp->hghsel;
 
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	if (mp->msgstats[msgnum] & SELECTED) {
+	if (is_selected (mp, msgnum)) {
 	    if ((fp = fopen (cp = m_name (msgnum), "r")) == NULL)
 		admonish (cp, "unable to read message");
 	    if (fp && pmatches (fp, msgnum, 0L, 0L)) {
@@ -217,9 +221,9 @@ main (int argc, char **argv)
 		    lo = msgnum;
 		if (msgnum > hi)
 		    hi = msgnum;
-	    }
-	    else {
-		mp->msgstats[msgnum] &= ~SELECTED;
+	    } else {
+		/* if it doesn't match, then unselect it */
+		unset_selected (mp, msgnum);
 		mp->numsel--;
 	    }
 	    if (fp)
@@ -237,22 +241,23 @@ main (int argc, char **argv)
 	if (zerosw && !m_seqnew (mp, seqs[seqp], publicsw))
 	    done (1);
 	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	    if (mp->msgstats[msgnum] & SELECTED)
+	    if (is_selected (mp, msgnum))
 		if (!m_seqadd (mp, seqs[seqp], msgnum, publicsw))
 		    done (1);
     }
 
     if (listsw) {
 	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	    if (mp->msgstats[msgnum] & SELECTED)
+	    if (is_selected (mp, msgnum))
 		printf ("%s\n", m_name (msgnum));
-    } else
+    } else {
 	printf ("%d hit%s\n", mp->numsel, mp->numsel == 1 ? "" : "s");
+    }
 
-    m_replace (pfolder, folder);
+    m_replace (pfolder, folder);	/* update current folder         */
     m_sync (mp);
-    m_update ();
-
+    m_fmsg (mp);			/* free folder/message structure */
+    m_update ();			/* update the context file       */
     done (0);
 }
 
