@@ -438,7 +438,7 @@ newnexus (int (*action)())
 {
     register struct nexus *p;
 
-    if ((p = (struct nexus *) calloc ((unsigned) 1, sizeof *p)) == NULL)
+    if ((p = (struct nexus *) calloc ((size_t) 1, sizeof *p)) == NULL)
 	adios (NULL, "unable to allocate component storage");
 
     p->n_action = action;
