@@ -1,6 +1,6 @@
 
 /*
- * rcvstore.c -- asynchronously incorporate new mail
+ * rcvstore.c -- asynchronously add mail to a folder
  *
  * $Id$
  */
@@ -133,6 +133,8 @@ main (int argc, char **argv)
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
+
+    /* read folder and create message structure */
     if (!(mp = m_gmsg (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
@@ -146,6 +148,7 @@ main (int argc, char **argv)
 	adios (tmpfilenam, "unable to create");
     chmod (tmpfilenam, m_gmprot ());
 
+    /* copy the message from stdin into temp file */
     cpydata (fileno (stdin), fd, "standard input", tmpfilenam);
 
     if (fstat (fd, &st) == NOTOK) {
@@ -168,7 +171,8 @@ main (int argc, char **argv)
 	    if (!(mp = m_remsg (mp, 0, mp->hghoff + MAXFOLDER)))
 		adios (NULL, "unable to allocate folder storage");
 
-	mp->msgstats[msgnum] |= EXISTS | UNSEEN;
+	set_exists (mp, msgnum);
+	set_unseen (mp, msgnum);
 	errno = 0;
     } while (link (tmpfilenam, m_name (msgnum)) == NOTOK && errno == EEXIST);
 
@@ -189,10 +193,10 @@ main (int argc, char **argv)
 	    done (1);
     }
 
-    m_setvis (mp, 0);
-    m_sync (mp);
-    m_update ();
-
+    m_setvis (mp, 0);	/* set the unseen sequence       */
+    m_sync (mp);	/* synchronize message sequences */
+    m_fmsg (mp);	/* free folder/message structure */
+    m_update ();	/* update the context file       */
     done (0);
 }
 
