@@ -377,23 +377,27 @@ try_it_again: ;
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
+
+    /* read folder and create message structure */
     if (!(mp = m_gmsg (folder)))
 	adios (NULL, "unable to read folder %s", folder);
+
     if (mp->hghmsg == 0)
 	adios (NULL, "no messages in %s", folder);
 
+    /* parse the message range/sequence/name and set SELECTED */
     if (!m_convert (mp, msg))
 	done (1);
-    m_setseq (mp);
+    m_setseq (mp);	/* set the previous-sequence */
 
     if (mp->numsel > 1)
 	adios (NULL, "only one message at a time!");
 
-    m_replace (pfolder, folder);
+    m_replace (pfolder, folder);	/* update current folder */
     if (mp->lowsel != mp->curmsg)
 	m_setcur (mp, mp->lowsel);
     m_sync (mp);
-    m_update ();
+    m_update ();			/* update the context file */
 
 go_to_it: ;
     msg = file ? file : getcpy (m_name (mp->lowsel));
