@@ -111,10 +111,9 @@ main (int argc, char **argv)
 
     if (rmf (folder) == OK && strcmp (m_find (pfolder), newfolder)) {
 	printf ("[+%s now current]\n", newfolder);
-	m_replace (pfolder, newfolder);
+	m_replace (pfolder, newfolder);	/* update current folder */
     }
-    m_update ();
-
+    m_update ();	/* update the context file */
     done (0);
 }
 
