@@ -1,6 +1,6 @@
 
 /*
- * scan.c -- display a one-line "scan" listing
+ * scan.c -- display a one-line "scan" listing of folder or messages
  *
  * $Id$
  */
@@ -182,7 +182,8 @@ main (int argc, char **argv)
 	    printf ("Folder %-32s%s\n\n", file,
 		    dasctime (dlocaltime (&clock), TW_NULL));
 	}
-#endif	/* JLR */
+#endif /* JLR */
+
 	m_unknown (in);
 	for (msgnum = 1; ; ++msgnum) {
 	    state = scan (in, msgnum, -1, nfs, width, 0, 0,
@@ -202,19 +203,23 @@ main (int argc, char **argv)
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
+
+    /* read folder and create message structure */
     if (!(mp = m_gmsg (folder)))
 	adios (NULL, "unable to read folder %s", folder);
+
     if (mp->hghmsg == 0)
 	adios (NULL, "no messages in %s", folder);
 
+    /* parse all the message ranges/sequences and set SELECTED */
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done(1);
-    m_setseq (mp);
+    m_setseq (mp);	/* set the previous-sequence */
 
-    m_replace (pfolder, folder);
+    m_replace (pfolder, folder);	/* update current folder   */
     m_sync (mp);
-    m_update ();
+    m_update ();			/* update the context file */
 
     if ((cp = m_find(usequence))) {
 	/* set bits for each unseen sequence */
@@ -238,13 +243,13 @@ main (int argc, char **argv)
     for (msgnum = revflag ? mp->hghsel : mp->lowsel;
 	    (revflag ? msgnum >= mp->lowsel : msgnum <= mp->hghsel);
 	    msgnum += revflag ? (-1) : 1)
-	if (mp->msgstats[msgnum] & SELECTED) {
+	if (is_selected(mp, msgnum)) {
 	    if ((in = fopen (cp = m_name (msgnum), "r")) == NULL) {
-#ifdef notdef
+#if 0
 		if (errno != EACCES)
 #endif
 		    admonish (cp, "unable to open message");
-#ifdef notdef
+#if 0
 		else
 		    printf ("%*d  unreadable\n", DMAXFOLDER, msgnum);
 #endif
@@ -261,7 +266,7 @@ main (int argc, char **argv)
 	    switch (state = scan (in, msgnum, 0, nfs, width,
 			msgnum == mp->curmsg,
 			mp->msgstats[msgnum] & bits,
-			hdrflag ? folder : (char *)0, 0L, 1)) {
+			hdrflag ? folder : (char *) 0, 0L, 1)) {
 		case SCNMSG: 
 		case SCNENC: 
 		case SCNERR: 
@@ -271,7 +276,7 @@ main (int argc, char **argv)
 		    adios (NULL, "scan() botch (%d)", state);
 
 		case SCNEOF: 
-#ifdef notdef
+#if 0
 		    printf ("%*d  empty\n", DMAXFOLDER, msgnum);
 #else
 		    advise (NULL, "message %d: empty", msgnum);
@@ -287,6 +292,7 @@ main (int argc, char **argv)
     m_sync (mp);	/* because formatsbr might have made changes */
 #endif
 
+    m_fmsg (mp);	/* free folder/message structure */
     if (clearflag)
 	clear_screen ();
 
