@@ -24,16 +24,15 @@
 #endif
 
 #define MAXSCANL 256		/* longest possible scan line */
-#define SBUFSIZ 512		/* buffer size for content part of header
-				 * fields.  We want this to be large
-				 * enough so that we don't do a lot of
-				 * extra FLDPLUS calls on m_getfld but
-				 * small enough so that we don't snarf
-				 * the entire message body when we're
-				 * only going to display 30 characters
-				 * of it.
-				 */
 
+/*
+ * buffer size for content part of header fields.  We want this
+ * to be large enough so that we don't do a lot of extra FLDPLUS
+ * calls on m_getfld but small enough so that we don't snarf
+ * the entire message body when we're only going to display 30
+ * characters of it.
+ */
+#define SBUFSIZ 512
 
 static struct format *fmt;
 #ifdef JLR
@@ -117,11 +116,10 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
 	FINDCOMP (cptr, "dtimenow");
 	if (cptr)
 	    cptr->c_text = getcpy(dtimenow ());
-	nxtbuf = compbuffers = (char **)calloc((unsigned) ncomps,
-	    sizeof(char *));
+	nxtbuf = compbuffers = (char **) calloc((size_t) ncomps, sizeof(char *));
 	if (nxtbuf == NULL)
 	    adios (NULL, "unable to allocate component buffers");
-	used_buf = (struct comp **)calloc((unsigned) (ncomps+1),
+	used_buf = (struct comp **) calloc((size_t) (ncomps+1),
 	    sizeof(struct comp *));
 	if (used_buf == NULL)
 	    adios (NULL, "unable to allocate component buffer stack");
@@ -237,14 +235,23 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
 		 */
 	body: 	;
 		while (state == BODY) {
+#ifdef LINUX_STDIO
+		    if (scnout->_IO_write_ptr == scnout->_IO_write_end) {
+#else
 		    if (scnout->_cnt <= 0) {
+#endif
 			if (fflush(scnout) == EOF)
 			    adios (scnmsg, "write error on");
 		    }
-		    state = m_getfld( state, name, scnout->_ptr,
-				      -(scnout->_cnt), inb );
+#ifdef LINUX_STDIO
+		    state = m_getfld(state, name, scnout->_IO_write_ptr,
+			(long)scnout->_IO_write_ptr-(long)scnout->_IO_write_end , inb);
+		    scnout->_IO_write_ptr += msg_count;
+#else
+		    state = m_getfld( state, name, scnout->_ptr, -(scnout->_cnt), inb );
 		    scnout->_cnt -= msg_count;
 		    scnout->_ptr += msg_count;
+#endif
 		}
 		goto finished;
 
@@ -303,7 +310,7 @@ finished:
 		if (! datecomp->c_text) {
 		    if (datecomp->c_tws == NULL)
 			datecomp->c_tws = (struct tws *)
-			    calloc((unsigned) 1, sizeof(*datecomp->c_tws));
+			    calloc((size_t) 1, sizeof(*datecomp->c_tws));
 		    if (datecomp->c_tws == NULL)
 			adios (NULL, "unable to allocate tws buffer");
   		    *datecomp->c_tws = *dlocaltime ((time_t *) &st.st_mtime);
