@@ -65,17 +65,18 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if (uleq (invo_name, "next"))
+    if (uleq (invo_name, "next")) {
 	mode = NEXT;
-    else
+    } else {
 	if (uleq (invo_name, "prev"))
 	    mode = PREV;
+    }
     if ((cp = m_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
@@ -185,8 +186,20 @@ main (int argc, char **argv)
     }
 #endif /* WHATNOW */
 
-    if (!msgp)
-	msgs[msgp++] = mode == NEXT ? "next" : mode == PREV ? "prev" : "cur";
+    if (!msgp) {
+	switch (mode) {
+	    case NEXT:
+		msgs[msgp++] = "next";
+		break;
+	    case PREV:
+		msgs[msgp++] = "prev";
+		break;
+	    default:
+		msgs[msgp++] = "cur";
+		break;
+	}
+    }
+
     if (!folder)
 	folder = m_getfolder ();
     maildir = m_maildir (folder);
@@ -255,11 +268,17 @@ use_mmp: ;
     }
 #endif /* MIME */
 
-    if (nshow)
+    if (nshow) {
 	proc = catproc;
-    else {
+    } else {
 	if (folder && !draftsw && !file)
 	    m_putenv ("mhfolder", folder);
+
+	/*
+	 * If we have "mhl" listed as our showproc, we
+	 * run it internally, and don't really exec
+	 * the mhl binary.
+	 */
 	if (strcmp (r1bindex (showproc, '/'), "mhl") == 0) {
 	    vec[0] = "mhl";
 	    mhl (vecp, vec);
@@ -268,10 +287,8 @@ use_mmp: ;
 	proc = showproc;
     }
 
-    if (!draftsw
-	    && !file
-	    && chdir (maildir = concat (m_maildir (""), "/", NULL))
-	    != NOTOK) {
+    if (!draftsw && !file
+	    && chdir (maildir = concat (m_maildir (""), "/", NULL)) != NOTOK) {
 	mp->foldpath = concat (mp->foldpath, "/", NULL);
 	cp = ssequal (maildir, mp->foldpath)
 	    ? mp->foldpath + strlen (maildir)
