@@ -40,9 +40,9 @@ static struct swit switches[] = {
     { "user name", 0 },
 #define	FILESW         2
     { "file file", 0 },
-#define	SENDSW         3
+#define	SENDERSW       3
     { "sender address", 0 },
-#define	MBOXSW         4
+#define	MAILBOXSW      4
     { "mailbox file", 0 },
 #define	HOMESW         5
     { "home directory", -4 },
@@ -150,8 +150,8 @@ static int timely (char *, char *);
 static int usr_file (int, char *, int);
 static int usr_pipe (int, char *, char *, char **);
 static RETSIGTYPE alrmser (int);
-static void copyinfo (FILE *fp, char *);
-static int copyfile (int, char *, int);
+static void get_sender (char *, char **);
+static int copy_message (int, char *, int);
 static void adorn (char *, char *, ...);
 static int suppress_duplicates (int, char *);
 
@@ -160,15 +160,16 @@ main (int argc, char **argv)
 {
     int fd, result;
     FILE *fp = stdin;
-    char *cp, *mdlvr = NULL, buf[100];
-    char from[BUFSIZ], mailbox[BUFSIZ];
-    char tmpfil[BUFSIZ], **argp = argv + 1;
+    char *cp, *mdlvr = NULL;
+    char buf[100];
+    char mailbox[BUFSIZ], tmpfil[BUFSIZ];
+    char **argp = argv + 1;
 
 #ifdef LOCALE
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (*argv, '/');
-    m_foil (NULL);
+    m_foil (NULL);		/* foil search of user profile */
     mts_init (invo_name);
 
     while ((cp = *argp++)) {
@@ -204,11 +205,11 @@ main (int argc, char **argv)
 		    if (!(file = *argp++) || *file == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
-		case SENDSW: 
+		case SENDERSW: 
 		    if (!(sender = *argp++))/* allow -xyz arguments */
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
-		case MBOXSW: 
+		case MAILBOXSW: 
 		    if (!(mbox = *argp++) || *mbox == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
@@ -300,14 +301,14 @@ main (int argc, char **argv)
 	    adios(file, "unable to open");
 	if (debug)
 	    fprintf (stderr, "retrieving message from file \"%s\"\n", file);
-	if ((fd = copyfile (tempfd, tmpfil, 1)) == -1)
+	if ((fd = copy_message (tempfd, tmpfil, 1)) == -1)
 	    adios (NULL, "unable to create temporary file");
 	close (tempfd);
     } else {
 	/* getting message from stdin */
 	if (debug)
 	    fprintf(stderr, "retrieving message from stdin\n");
-	if ((fd = copyfile (fileno (stdin), tmpfil, 1)) == -1)
+	if ((fd = copy_message (fileno (stdin), tmpfil, 1)) == -1)
 	    adios (NULL, "unable to create temporary file");
     }
     if (debug)
@@ -318,9 +319,12 @@ main (int argc, char **argv)
     if (!(fp = fdopen (fd, "r+")))
 	adios (NULL, "unable to access temporary file");
 
-    from[0] = 0;
+    /*
+     * If no sender given, extract it
+     * from envelope information.
+     */
     if (sender == NULL)
-	copyinfo (fp, from);
+	get_sender (envelope, &sender);
 
     if (mbox == NULL) {
 	sprintf (mailbox, "%s/%s",
@@ -336,9 +340,9 @@ main (int argc, char **argv)
 	fprintf (stderr, "user=\"%s\"\n", user);
 	fprintf (stderr, "info=\"%s\"\n", info);
 	fprintf (stderr, "sender=\"%s\"\n", sender);
+	fprintf (stderr, "envelope=\"%s\"\n", envelope ? envelope : "");
 	fprintf (stderr, "mbox=\"%s\"\n", mbox);
 	fprintf (stderr, "home=\"%s\"\n", home);
-	fprintf (stderr, "from=\"%s\"\n", from);
 	fprintf (stderr, "ddate=\"%s\"\n", ddate);
 	fprintf (stderr, "now=%02d:%02d\n\n", now->tw_hour, now->tw_min);
     }
@@ -883,7 +887,7 @@ usr_hook (int fd, char *mailbox)
     int i, vecp;
     char receive[BUFSIZ], tmpfil[BUFSIZ], *vec[NVEC];
 
-    if ((fd = copyfile (fd, tmpfil, 0)) == NOTOK) {
+    if ((fd = copy_message (fd, tmpfil, 0)) == NOTOK) {
 	if (verbose)
 	    adorn ("unable to copy message; skipping hook\n");
 	return NOTOK;
@@ -1032,29 +1036,19 @@ alrmser (int i)
  */
 
 static void
-copyinfo (FILE *fp, char *from)
+get_sender (char *envelope, char **sender)
 {
     int i;
     register char *cp;
-    static char buffer[BUFSIZ];
+    char buffer[BUFSIZ];
 
-    /*
-     * copy of the envelope information
-     * ("From " line) from copyfile
-     */
-    if (envelope)
-	strcpy (from, envelope);
-    else if (fgets (from, BUFSIZ, fp) == NULL)
-	adios (NULL, "no message");
-
-    i = strlen ("From ");
-    if (strncmp (from, "From ", i)) {
-	rewind (fp);
-	*from = 0;
+    if (envelope == NULL) {
+	*sender = getcpy ("");
 	return;
     }
 
-    strcpy (buffer, from + i);
+    i = strlen ("From ");
+    strcpy (buffer, envelope + i);
     if ((cp = strchr(buffer, '\n'))) {
 	*cp = 0;
 	cp -= 24;
@@ -1070,18 +1064,18 @@ copyinfo (FILE *fp, char *from)
 	    *cp = 0;
 	else
 	    break;
-    sender = buffer;
-    rewind (fp);
+    *sender = getcpy (buffer);
 }
 
 
 /*
- * Copy message into a temporary file,
- * and do processing of the message headers.
+ * Copy message into a temporary file.
+ * While copying, it will do some header processing
+ * including the extraction of the envelope information.
  */
 
 static int
-copyfile (int qd, char *tmpfil, int fold)
+copy_message (int qd, char *tmpfil, int fold)
 {
     register int i, first = 1, fd1, fd2;
     char buffer[BUFSIZ];
@@ -1137,7 +1131,8 @@ you_lose: ;
 
     /*
      * copy message into temporary file
-     * and massage the headers
+     * and massage the headers.  Save
+     * a copy of the "From " line for later.
      */
     i = strlen ("From ");
     while (fgets (buffer, sizeof(buffer), qfp)) {
@@ -1147,7 +1142,7 @@ you_lose: ;
 #ifdef RPATHS
 		char *fp, *cp, *hp, *ep;
 #endif
-		/* save "From " line for later */
+		/* get copy of envelope information ("From " line) */
 		envelope = getcpy (buffer);
 
 #if 0
