@@ -1116,7 +1116,7 @@ linsert (WINDOW *w)
     register char *cp;
     register struct line *lp;
 
-    if ((lp = (struct line  *) calloc ((unsigned) 1, sizeof *lp)) == NULL)
+    if ((lp = (struct line *) calloc ((size_t) 1, sizeof *lp)) == NULL)
 	adios (NULL, "unable to allocate line storage");
 
     lp->l_no = (ltail ? ltail->l_no : 0) + 1;
