@@ -42,7 +42,7 @@ rcinit (int rfd, int wfd)
 
     if ((cp = getenv ("MHVDEBUG")) && *cp) {
 	sprintf (buffer, "%s.out", invo_name);
-	if (fp = fopen (buffer, "w")) {
+	if ((fp = fopen (buffer, "w"))) {
 	  fseek (fp, 0L, 2);
 	  fprintf (fp, "%d: rcinit (%d, %d)\n", getpid (), rfd, wfd);
 	  fflush (fp);
