@@ -350,7 +350,7 @@ gethostbystring (char *s)
 #ifdef DG
     if (iaddr.s_addr == NOTOK && strcmp (s, "255.255.255.255"))
 #else
-    if (iaddr == NOTOK && strcmp (s, "255.255.255.255"))
+    if (((int) iaddr == NOTOK) && strcmp (s, "255.255.255.255"))
 #endif
 	return gethostbyname (s);
 
